"""Documentation for the h7_env_manager package.

This package provides utilities for managing environment variables in a project.
"""

# Package version
__version__ = "1.0.2"

# Import main class to make it available at package level
from .env_manager import EnvManager as EnvManager
